summaryrefslogtreecommitdiffstats
path: root/application/controllers/file.php
diff options
context:
space:
mode:
authorFlorian Pritz <bluewind@xinu.at>2013-09-04 16:37:32 +0200
committerFlorian Pritz <bluewind@xinu.at>2013-09-04 16:37:32 +0200
commit855b7b25aeba021400aa6a3438e2ab19c3b63907 (patch)
treee8790191e864b2acd4bd9a8232d8d457c943026f /application/controllers/file.php
parentcce1fe9bfea359cebae585eaaa944650bace4966 (diff)
Replace is_cli_client() with stateful_client where applicable
Stateless clients (cli client and clients using api keys) can't reclaim IDs (no cookie) so they should be required to log in asap and they will always get an error if they didn't log in. Signed-off-by: Florian Pritz <bluewind@xinu.at>
Diffstat (limited to 'application/controllers/file.php')
-rw-r--r--application/controllers/file.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/application/controllers/file.php b/application/controllers/file.php
index 6a97c645f..98ccae884 100644
--- a/application/controllers/file.php
+++ b/application/controllers/file.php
@@ -582,9 +582,9 @@ class File extends MY_Controller {
// Handle pastes
function do_paste()
{
// desktop clients get a cookie to claim the ID later
// don't force them to log in just yet
- if (is_cli_client()) {
+ if (!stateful_client()) {
$this->muser->require_access();
}
@@ -617,9 +617,9 @@ class File extends MY_Controller {
// Handles uploaded files
function do_upload()
{
// desktop clients get a cookie to claim the ID later
// don't force them to log in just yet
- if (is_cli_client()) {
+ if (!stateful_client()) {
$this->muser->require_access("apikey");
}
@@ -582,9 +582,9 @@ class File extends MY_Controller {
function do_paste()
{
- // desktop clients get a cookie to claim the ID later
+ // stateful clients get a cookie to claim the ID later
// don't force them to log in just yet
@@ -617,9 +617,9 @@ class File extends MY_Controller {
function do_upload()
{
- // desktop clients get a cookie to claim the ID later
+ // stateful clients get a cookie to claim the ID later
// don't force them to log in just yet